%define libname libcurl

Name:          curl
Version:       7.50.2
Release:       1mamba
Summary:       A tool for transfering data with URL syntax that supports many protocols
Group:         Applications/Networking
Vendor:        openmamba
Distribution:  openmamba
Packager:      Davide Madrisan <davide.madrisan@gmail.com>
URL:           http://curl.haxx.se
Source:        http://curl.haxx.se/download/curl-%{version}.tar.bz2
Patch0:        %{name}-7.21.2-gnutls.patch
Patch1:        curl-7.34.0-dns-resolver-prefer-ipv4.patch
Patch2:        curl-7.40.0-libgss-1.0.3.patch
License:       MIT
BuildRequires: bash
BuildRequires: ldconfig
BuildRequires: libgssapi-devel
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: libcares-devel
BuildRequires: libe2fs-devel
BuildRequires: libgcrypt-devel
BuildRequires: libgnutls-devel
BuildRequires: libgpg-error-devel
%if "%{stage1}" != "1"
BuildRequires: libidn-devel
BuildRequires: libopenldap-devel
BuildRequires: libsasl-devel
BuildRequires: libkrb5-devel
%endif
BuildRequires: libopenssl-devel
BuildRequires: libssh2-devel
BuildRequires: libz-devel
## AUTOBUILDREQ-END
BuildRequires: pkgconfig
BuildRequires: libopenssl-devel >= 1.0.2
%if "%{stage1}" != "1"
BuildRequires: groff
%endif
BuildRequires: perl
Provides:      curl-gnutls
Obsoletes:     curl-gnutls
BuildRoot:     %{_tmppath}/%{name}-%{version}-root

# FIXME, not compiled in:
#  krb4 support:    no      (--with-krb4*)
#  SPNEGO support:  no      (--with-spnego)

# LDAPS support:   no      (--enable-ldaps)
#  SSPI support:    no      (--enable-sspi)
#  ca cert path:    no

%description
Curl is a tool for transfering data with URL syntax, supporting FTP, FTPS, HTTP, HTTPS, GOPHER, TELNET, DICT, FILE and LDAP.
This tool offer a myriad of powerful features and full protocol control.

%package -n %{libname}
Summary:       Dynamic Libraries for cURL
Group:         System/Libraries
Provides:      %{libname}-gnutls
Obsoletes:     %{libname}-gnutls
%if "%{stage1}" != "1"
Requires:      ca-certificates
%endif

%description -n %{libname}
Libcurl is a library for transfering data with URL syntax, supporting FTP, FTPS, HTTP, HTTPS, GOPHER, TELNET, DICT, FILE and LDAP.
This library offer a myriad of powerful features and full protocol control.

%package -n %{libname}-devel
Summary:       Static libraries and header for %{libname}
Group:         Development/Libraries
Requires:      %{libname} = %{?epoch:%epoch:}%{version}-%{release}
Provides:      %{libname}-gnutls-devel
Obsoletes:     %{libname}-gnutls-devel

%description -n %{libname}-devel
Curl is a tool and libcurl is a library for transfering data with URL syntax, supporting FTP, FTPS, HTTP, HTTPS, GOPHER, TELNET, DICT, FILE and LDAP.
The tool and library offer a myriad of powerful features and full protocol control.

This package contains static libraries and header files need for development.

%prep
%setup -q
%patch1 -p1
#%patch2 -p1

%build
%configure \
   --enable-shared \
   --enable-static \
   --enable-cookies \
   --enable-crypto-auth \
   --enable-http \
   --enable-ftp \
   --enable-file \
   --enable-dict \
   --enable-telnet \
   --enable-tftp \
   --enable-ipv6 \
   --with-ssl \
   --with-gnutls \
   --with-zlib \
   --with-random \
   --with-nss \
   --enable-verbose \
   --disable-sspi \
   --with-libssh2 \
%if "%{stage1}" != "1"
   --with-gssapi \
   --enable-ldap \
   --with-libidn \
   --enable-manual \
   --with-ca-bundle=%{_sysconfdir}/pki/tls/certs/ca-bundle.crt \
%else
   --without-krb5 \
%endif
   --enable-ares

#  --enable-hidden-symbols
#  --with-spnego

%make \
%if "%{_host}" != "%{_build}"
   CFLAGS="-lcares -lssh2"
%endif

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
# install development documentation
install -d curls_develpck_docs
install -m644 \
   CHANGES COPYING README RELEASE-NOTES \
   docs/BUGS docs/FAQ docs/FEATURES docs/KNOWN_BUGS \
   docs/MANUAL docs/THANKS docs/TODO \
   curls_develpck_docs/

install -d curls_develpck_docs/{libcurl,examples}
#install -m644 docs/libcurl/libcurl.m4 curls_develpck_docs/libcurl/libcurl.m4
install -m644 docs/examples/{Makefile.example,README,*.c} \
   curls_develpck_docs/examples/

%makeinstall

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/curl
#%{_datadir}/zsh/site-functions/_curl
%{_mandir}/man1/curl.*

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libcurl.so.*
%doc COPYING

%files -n %{libname}-devel
%defattr(-,root,root)
%{_bindir}/curl-config
%{_includedir}/curl/
%{_libdir}/libcurl.a
%{_libdir}/libcurl.la
%{_libdir}/libcurl.so
%{_libdir}/pkgconfig/libcurl.pc
%{_datadir}/aclocal/libcurl.m4
%{_mandir}/man1/curl-config.1*
#%{_mandir}/man1/mk-ca-bundle.1*
%{_mandir}/man3/*
%doc curls_develpck_docs/*
%doc docs/BUGS docs/FAQ docs/FEATURES
%doc docs/KNOWN_BUGS docs/MANUAL docs/THANKS docs/TODO
%doc CHANGES README RELEASE-NOTES

%changelog
* Fri Sep 09 2016 Automatic Build System <autodist@mambasoft.it> 7.50.2-1mamba
- automatic version update by autodist

* Wed Aug 03 2016 Automatic Build System <autodist@mambasoft.it> 7.50.1-1mamba
- automatic version update by autodist

* Thu Jul 21 2016 Automatic Build System <autodist@mambasoft.it> 7.50.0-1mamba
- automatic version update by autodist

* Mon May 30 2016 Automatic Build System <autodist@mambasoft.it> 7.49.1-1mamba
- automatic version update by autodist

* Fri May 20 2016 Automatic Build System <autodist@mambasoft.it> 7.49.0-1mamba
- automatic version update by autodist

* Tue May 03 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 7.48.0-2mamba
- rebuilt with openssl 1.0.2

* Wed Mar 23 2016 Automatic Build System <autodist@mambasoft.it> 7.48.0-1mamba
- automatic version update by autodist

* Mon Feb 08 2016 Automatic Build System <autodist@mambasoft.it> 7.47.1-1mamba
- automatic version update by autodist

* Wed Jan 27 2016 Automatic Build System <autodist@mambasoft.it> 7.47.0-1mamba
- automatic version update by autodist

* Thu Dec 03 2015 Automatic Build System <autodist@mambasoft.it> 7.46.0-1mamba
- automatic version update by autodist

* Wed Oct 07 2015 Automatic Build System <autodist@mambasoft.it> 7.45.0-1mamba
- automatic version update by autodist

* Wed Aug 12 2015 Automatic Build System <autodist@mambasoft.it> 7.44.0-1mamba
- automatic version update by autodist

* Wed Jun 17 2015 Automatic Build System <autodist@mambasoft.it> 7.43.0-1mamba
- automatic version update by autodist

* Wed Apr 29 2015 Automatic Build System <autodist@mambasoft.it> 7.42.1-1mamba
- automatic version update by autodist

* Fri Apr 24 2015 Automatic Build System <autodist@mambasoft.it> 7.42.0-1mamba
- automatic version update by autodist

* Sun Mar 15 2015 Automatic Build System <autodist@mambasoft.it> 7.41.0-1mamba
- automatic version update by autodist

* Wed Jan 21 2015 Automatic Build System <autodist@mambasoft.it> 7.40.0-1mamba
- automatic version update by autodist

* Wed Nov 05 2014 Automatic Build System <autodist@mambasoft.it> 7.39.0-1mamba
- automatic version update by autodist

* Wed Sep 10 2014 Automatic Build System <autodist@mambasoft.it> 7.38.0-1mamba
- automatic version update by autodist

* Thu Jul 17 2014 Automatic Build System <autodist@mambasoft.it> 7.37.1-1mamba
- automatic version update by autodist

* Wed May 21 2014 Automatic Build System <autodist@mambasoft.it> 7.37.0-1mamba
- automatic version update by autodist

* Wed Mar 26 2014 Automatic Build System <autodist@mambasoft.it> 7.36.0-1mamba
- automatic version update by autodist

* Wed Jan 29 2014 Automatic Build System <autodist@mambasoft.it> 7.35.0-1mamba
- automatic version update by autodist

* Wed Dec 25 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 7.34.0-2mamba
- repatched to prefer ipv4 address resolution

* Wed Dec 18 2013 Automatic Build System <autodist@mambasoft.it> 7.34.0-1mamba
- automatic version update by autodist

* Tue Oct 15 2013 Automatic Build System <autodist@mambasoft.it> 7.33.0-1mamba
- automatic version update by autodist

* Mon Aug 12 2013 Automatic Build System <autodist@mambasoft.it> 7.32.0-1mamba
- automatic version update by autodist

* Sat Jun 22 2013 Automatic Build System <autodist@mambasoft.it> 7.31.0-1mamba
- automatic version update by autodist

* Fri Apr 12 2013 Automatic Build System <autodist@mambasoft.it> 7.30.0-1mamba
- automatic version update by autodist

* Wed Feb 06 2013 Automatic Build System <autodist@mambasoft.it> 7.29.0-1mamba
- automatic version update by autodist

* Tue Nov 20 2012 Automatic Build System <autodist@mambasoft.it> 7.28.1-1mamba
- update to 7.28.1

* Thu Oct 11 2012 Automatic Build System <autodist@mambasoft.it> 7.28.0-1mamba
- automatic version update by autodist

* Sat Jul 28 2012 Automatic Build System <autodist@mambasoft.it> 7.27.0-1mamba
- automatic version update by autodist

* Wed Jun 06 2012 Automatic Build System <autodist@mambasoft.it> 7.26.0-1mamba
- automatic version update by autodist

* Fri Mar 23 2012 Automatic Build System <autodist@mambasoft.it> 7.25.0-1mamba
- automatic version update by autodist

* Thu Jan 26 2012 Automatic Build System <autodist@mambasoft.it> 7.24.0-1mamba
- automatic version update by autodist

* Fri Nov 18 2011 Automatic Build System <autodist@mambasoft.it> 7.23.1-1mamba
- automatic version update by autodist

* Wed Nov 16 2011 Automatic Build System <autodist@mambasoft.it> 7.23.0-1mamba
- automatic version update by autodist

* Wed Sep 14 2011 Automatic Build System <autodist@mambasoft.it> 7.22.0-1mamba
- automatic version update by autodist

* Thu Jun 23 2011 Automatic Build System <autodist@mambasoft.it> 7.21.7-1mamba
- automatic update by autodist

* Sun Apr 24 2011 Davide Madrisan <davide.madrisan@gmail.com> 7.21.6-1mamba
- update to 7.21.6

* Mon Apr 18 2011 Automatic Build System <autodist@mambasoft.it> 7.21.5-1mamba
- automatic update by autodist

* Sat Mar 05 2011 Automatic Build System <autodist@mambasoft.it> 7.21.4-1mamba
- automatic update by autodist

* Thu Oct 14 2010 Davide Madrisan <davide.madrisan@gmail.com> 7.21.2-1mamba
- update to 7.21.2

* Wed Jun 16 2010 Automatic Build System <autodist@mambasoft.it> 7.21.0-1mamba
- automatic update to 7.21.0 by autodist

* Fri May 28 2010 Automatic Build System <autodist@mambasoft.it> 7.20.1-1mamba
- automatic update to 7.20.1 by autodist

* Tue Feb 09 2010 Automatic Build System <autodist@mambasoft.it> 7.20.0-1mamba
- automatic update to 7.20.0 by autodist

* Wed Nov 04 2009 Automatic Build System <autodist@mambasoft.it> 7.19.7-1mamba
- automatic update to 7.19.7 by autodist

* Thu Aug 13 2009 Automatic Build System <autodist@mambasoft.it> 7.19.6-1mamba
- automatic update to 7.19.6 by autodist

* Mon May 18 2009 Automatic Build System <autodist@mambasoft.it> 7.19.5-1mamba
- automatic update to 7.19.5 by autodist

* Tue Mar 03 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 7.19.4-1mamba
- automatic update to 7.19.4 by autodist

* Wed Jan 21 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 7.19.3-1mamba
- automatic update to 7.19.3 by autodist

* Fri Nov 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.19.2-1mamba
- automatic update to 7.19.2 by autodist

* Wed Nov 12 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.19.1-1mamba
- automatic update to 7.19.1 by autodist

* Tue Oct 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.19.0-2mamba
- enabled static library build as required by pycurl
- added a patch that enables ipv4 search by default insted of ipv6; use -6 to force ipv6 lookups

* Sun Oct 12 2008 gil <puntogil@libero.it> 7.19.0-1mamba
- update to 7.19.0 

* Fri Aug 29 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.18.2-1mamba
- update to 7.18.2

* Thu Jun 05 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.18.1-2mamba
- added build of curl-gnutls packages

* Tue Jun 03 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 7.18.1-1mamba
- update to 7.18.1

* Tue Nov 20 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 7.17.1-1mamba
- update to 7.17.1
- rebuild with c-ares support (async DNS queries)

* Sun Oct 14 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 7.17.0-1mamba
- update to 7.17.0

* Thu Jul 12 2007 Aleph0 <aleph0@openmamba.org> 7.16.4-2mamba
- add all the available documentation for developers to the devel subpackage

* Wed Jul 11 2007 Aleph0 <aleph0@openmamba.org> 7.16.4-1mamba
- update to 7.16.4

* Thu Apr 12 2007 Davide Madrisan <davide.madrisan@gmail.com> 7.16.2-2mamba
- esnabled LIBSSH2 support

* Thu Apr 12 2007 Davide Madrisan <davide.madrisan@gmail.com> 7.16.2-1mamba
- update to version 7.16.2 by autospec
- do not build the static library
- enabled GSSAPI support

* Mon Apr 02 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 7.16.1-1mamba
- update to version 7.16.1 by autospec

* Tue Jun 13 2006 Davide Madrisan <davide.madrisan@qilinux.it> 7.15.4-1qilnx
- update to version 7.15.4 by autospec

* Mon Mar 20 2006 Davide Madrisan <davide.madrisan@qilinux.it> 7.15.3-1qilnx
- update to version 7.15.3 by autospec
- also fixes the TFTP packet buffer overflow vulnerability

* Thu Mar 02 2006 Davide Madrisan <davide.madrisan@qilinux.it> 7.15.2-1qilnx
- update to version 7.15.2 by autospec

* Wed Dec 07 2005 Davide Madrisan <davide.madrisan@qilinux.it> 7.15.1-1qilnx
- update to version 7.15.1 by autospec

* Mon Oct 17 2005 Davide Madrisan <davide.madrisan@qilinux.it> 7.15.0-1qilnx
- update to version 7.15.0 by autospec
- also fixes the security issue QSA-2005-120 (CAN-2005-3185)

* Sun Oct 02 2005 Davide Madrisan <davide.madrisan@qilinux.it> 7.14.1-2qilnx
- new package curl
- curl-config manpage moved to devel package
- own %{_datadir}/curl and %{_includedir}/curl

* Wed Sep 07 2005 Davide Madrisan <davide.madrisan@qilinux.it> 7.14.1-1qilnx
- update to version 7.14.1 by autospec

* Mon Mar 07 2005 Davide Madrisan <davide.madrisan@qilinux.it> 7.13.1-1qilnx
- update to version 7.13.1 by autospec
- also include security fix (CAN-2005-0490)
- added missing build requirement: libidn-devel, libkrb5-devel

* Mon Jul 26 2004 Davide Madrisan <davide.madrisan@qilinux.it> 7.12.0-1qilnx
- first build
